<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:eu-application="http://pharmacos.eudra.org/eu-application"
	xmlns:xlink="http://www.w3c.org/1999/xlink">

	<xsl:template match="/">
		<!--
	*********************************************************************************
		*****
		***** STYLESHEET
		*****	NOTICE TO APPLICANTS	
		*****	Module 1: Administrative information
		*****	Application form - renewal
		*****	February 2007
		*****
	-->
		<html>
			<style>h3{page-break-before:always}</style>
			<style>page {counter-increment:page}</style>
			<style>body {font-family: Arial, Helvetica, sans-serif; font-size: 10pt}</style>
			<style>table {font-family: Arial, Helvetica, sans-serif; font-size: 10pt}</style>
			<style>ol, ul {margin-bottom: 0px; margin-top: 0px;}</style>
			<style>.level-1 {margin-left: 15px}</style>
			<style>.level-2 {margin-left: 50px}</style>
			<body>
				<xsl:apply-templates select="//application"/>
				<xsl:apply-templates select="//declaration"/>
				<xsl:call-template name="decision"/>
				<xsl:apply-templates select="//maa-particulars/manufacturers"/>
				<xsl:apply-templates select="//maa-particulars/qualitative-quantitative-composition"/>
				<xsl:apply-templates select="//present-proposed-changes"/>
				<xsl:apply-templates select="//amended-product-information"/>
				<xsl:apply-templates select="//declaration-info"/>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="application">
		<p align="right">Revision February 2007</p>
		<center>
			<font size="+1"><b>APPLICATION FOR RENEWAL OF A MARKETING AUTHORISATION</b></font>
			<br/><br/>
			<table width="100%" cellpadding="5" cellspacing="0" border="1" frame="box" rules="groups">
				<tbody>
					<tr>
						<td width="50%" align="center">
							<br/>
							<b>HUMAN</b>
							<xsl:text>   </xsl:text>
							<xsl:if test="count(//domaine/human) = 0"><input type="checkbox"/></xsl:if>
							<xsl:if test="count(//domaine/human) > 0"><input type="checkbox" checked="checked"/></xsl:if>
						</td>
						<td width="50%" align="center">
							<br/>
							<b>VETERINARY</b>
							<xsl:text>   </xsl:text>
							<xsl:if test="count(//domaine/veterinary) = 0"><input type="checkbox"/></xsl:if>
							<xsl:if test="count(//domaine/veterinary) > 0"><input type="checkbox" checked="checked"/></xsl:if>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="100%" cellpadding="0">
								<tr>
									<td width="45%">
										<b>NATIONAL AUTHORISATION IN MRP</b>
									</td>
									<td width="5%">
										<xsl:if test="count(//type-procedure/mutual-recognition-procedure) = 0"><input type="checkbox"/></xsl:if>
										<xsl:if test="count(//type-procedure/mutual-recognition-procedure) > 0"><input type="checkbox" checked="checked"/></xsl:if>
									</td>
									<td width="50%">
										<b>MRP procedure number<sup>1</sup>:</b>
										<xsl:text>   </xsl:text>
										<xsl:apply-templates select="//type-procedure/mutual-recognition-procedure/mrp-procedure-number" mode="data"/>
									</td>
								</tr>
								<tr>
									<td>
										<b>COMMUNITY AUTHORISATION</b>
									</td>
									<td width="10%">
										<xsl:if test="count(//type-procedure/centralised-procedure ) = 0"><input type="checkbox"/></xsl:if>
										<xsl:if test="count(//type-procedure/centralised-procedure ) > 0"><input type="checkbox" checked="checked"/></xsl:if>
									</td>
									<td></td>
								</tr>
								<tr>
									<td>
										<b>NATIONAL AUTHORISATION ONLY</b>
									</td>
									<td width="10%">
										<xsl:if test="count(//type-procedure/national-procedure) = 0"><input type="checkbox"/></xsl:if>
										<xsl:if test="count(//type-procedure/national-procedure) > 0"><input type="checkbox" checked="checked"/></xsl:if>
									</td>
									<td></td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<br/>Reference Member State:<br/>
							<xsl:call-template name="member-state">
								<xsl:with-param name="role">rms</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<br/>Concerned Member States:<br/>
							<xsl:call-template name="member-state">
								<xsl:with-param name="role">cms</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
				</tbody>
				<tbody>
					<tr>
						<td>
							Is the product currently marketed?
							Yes 
							<xsl:if test="count(//product-currently-marketed/concerned-member-state) = 0"><input type="checkbox"/></xsl:if>
							<xsl:if test="count(//product-currently-marketed/concerned-member-state) > 0"><input type="checkbox" checked="checked"/></xsl:if>
							<xsl:text>     </xsl:text>
							No
							<xsl:if test="count(//product-currently-marketed/no-product-currently-marketed) = 0"><input type="checkbox"/></xsl:if>
							<xsl:if test="count(//product-currently-marketed/no-product-currently-marketed) > 0"><input type="checkbox" checked="checked"/></xsl:if>
						</td>
						<td>
							If yes, in which Member States<sup>2</sup>?
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:call-template name="member-state">
								<xsl:with-param name="role">mms</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
				</tbody>
			</table>
		</center>
		<br/>
	</xsl:template>
	
	<xsl:template match="node()|@*" mode="data">
		<font color="blue">
			<xsl:value-of select="."/>
		</font>
	</xsl:template>
	
	<xsl:template match="node()|@*" mode="data-pre">
		<font color="blue">
			<pre><font style="font-family: Arial, Helvetica, sans-serif; font-size: 10pt"><xsl:value-of select="."/></font></pre>
		</font>
	</xsl:template>
	
	<xsl:template match="node()|@*" mode="line">
		<font color="blue">
			<xsl:value-of select="."/>
		</font><br/>
	</xsl:template>
	
	<xsl:template match="*" mode="csv">
		<xsl:apply-templates select="." mode="data"/>
		<xsl:if test="position() != last()">, </xsl:if>
	</xsl:template>
	
	<xsl:template name="checkbox">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$value = 0">
				<input type="checkbox"/>
			</xsl:when>
			<xsl:otherwise>
				<input type="checkbox" checked="checked"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="*" mode="data-date">
		<font color="blue">
			<xsl:value-of select="@year"/>-<xsl:value-of select="@month"/>-<xsl:value-of select="@day"/>
		</font>
	</xsl:template>
	
	<xsl:template name="ms">
		<xsl:param name="code"/>
		<xsl:param name="width"/>
		<xsl:param name="role"/>
		
		<td>
			<xsl:if test="string-length($width) > 0">
				<xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="$role = 'cms'">
				<xsl:choose>
					<xsl:when test="$code = 'NONE'">
						<xsl:if test="count(//mutual-recognition-procedure/no-concerned-member-state) = 0"><input type="checkbox"/></xsl:if>
						<xsl:if test="count(//mutual-recognition-procedure/no-concerned-member-state) > 0"><input type="checkbox" checked="checked"/></xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="count(//mutual-recognition-procedure/concerned-member-state/eu-member-state[./@state = $code]) = 0"><input type="checkbox"/></xsl:if>
						<xsl:if test="count(//mutual-recognition-procedure/concerned-member-state/eu-member-state[./@state = $code]) > 0"><input type="checkbox" checked="checked"/></xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:if test="$role = 'rms'">
				<xsl:if test="count(//mutual-recognition-procedure/eu-member-state[./@state = $code]) = 0"><input type="checkbox"/></xsl:if>
				<xsl:if test="count(//mutual-recognition-procedure/eu-member-state[./@state = $code]) > 0"><input type="checkbox" checked="checked"/></xsl:if>
			</xsl:if>
			<xsl:if test="$role = 'mms'">
				<xsl:if test="count(//product-currently-marketed/concerned-member-state/eu-member-state[./@state = $code]) = 0"><input type="checkbox"/></xsl:if>
				<xsl:if test="count(//product-currently-marketed/concerned-member-state/eu-member-state[./@state = $code]) > 0"><input type="checkbox" checked="checked"/></xsl:if>
			</xsl:if>
			<xsl:value-of select="$code"/>
		</td>
		
	</xsl:template>
	
	<xsl:template name="member-state">
		<xsl:param name="role"/>
		<table width="100%" cellpadding="0" cellspacing="0">
			<tr>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">AT</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">BE</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">BG</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">CY</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">CZ</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">DE</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">DK</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">EE</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">EL</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">ES</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">FI</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">FR</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">HU</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">IE</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">IS</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
			</tr>
			<tr>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">IT</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">LI</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">LT</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">LU</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">LV</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">MT</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">NL</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">NO</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">PL</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">PT</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">RO</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">SE</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">SI</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">SK</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ms">	
					<xsl:with-param name="code">UK</xsl:with-param>
					<xsl:with-param name="width">6%</xsl:with-param>
					<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
				</xsl:call-template>
			</tr>
			<xsl:if test="$role='cms'">
				<tr>
					<xsl:call-template name="ms">	
						<xsl:with-param name="code">NONE</xsl:with-param>
						<xsl:with-param name="width">6%</xsl:with-param>
						<xsl:with-param name="role"><xsl:value-of select="$role"/></xsl:with-param>
					</xsl:call-template>
				</tr>
			</xsl:if>
		</table>
	</xsl:template>
	
	<xsl:template match="*" mode="annex">
		<xsl:if test="position() = 1">
			<br/>
		</xsl:if>
		<font face="Arial" size="2">
			<a>
				<xsl:attribute name="href">
					<xsl:value-of select="@xlink:href"/>
				</xsl:attribute>
				<xsl:value-of select="@xlink:href"/>
			</a>
		</font>
		<xsl:if test="position() != last()">,</xsl:if>
	</xsl:template>
	
	<xsl:template match="atc-class" mode="def">
		<tr>
			<td valign="top"><xsl:apply-templates select="atc-code" mode="data"/></td>
			<td valign="top"><xsl:apply-templates select="atc-name" mode="data"/></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="declaration">
		<center>
			<table width="100%" cellpadding="5" cellspacing="0" border="1" frame="border" rules="all">
				<tr>
					<td width="50%" valign="top">
						(Invented)Name: 
						<xsl:apply-templates select="invented-name" mode="data"/><br/>
						<br/>
						
						Active substance(s):<br/>
						<xsl:if test="count(//national-mrp-products) > 0">
							<xsl:apply-templates select="substance-name" mode="csv"/><br/>
						</xsl:if>
						<br/>
						
						Pharmacotherapeutic classification (Group + ATC code):
						<table width="100%" cellpadding="0" cellspacing="0">
							<xsl:apply-templates select="atc-class" mode="def"/>
						</table><br/>
						
						Pharmaceutical form(s) and strength(s)<sup>3</sup>: <br/>
						<xsl:for-each select="//national-mrp-products">
							<xsl:apply-templates select="form-name" mode="data"/><br/>
							<xsl:apply-templates select="strength-quantity" mode="data"/><xsl:text> </xsl:text><xsl:apply-templates select="strength-unit" mode="data"/><br/>
						</xsl:for-each>
						<xsl:for-each select="//centralised-products">
							<xsl:apply-templates select="form-name" mode="data"/>, 
							<xsl:apply-templates select="strength-quantity" mode="data"/><xsl:text> </xsl:text><xsl:apply-templates select="strength-unit" mode="data"/>, 
							<xsl:apply-templates select="pack-size" mode="data"/><br/>
						</xsl:for-each>
						<br/>
						
						Route(s) of administration<sup>3</sup> :<br/>
						<xsl:apply-templates select="routes/route-name" mode="csv"/><br/>
						<br/>
						
						Target species<sup>3</sup> :<br/>
						<xsl:apply-templates select="target-species" mode="csv"/><br/>
						<br/>
						
						MA number(s)<sup>3</sup>: <br/>
						<xsl:apply-templates select="manufacturing-aut-number" mode="csv"/><br/>
						<br/>
						
					</td>
					<td width="50%" valign="top">
						Name and address of MA holder:<br/>
						<xsl:apply-templates select="declaration-contact/dossier/marketing-holder/company-name" mode="data"/><br/>
						<xsl:apply-templates select="declaration-contact/dossier/marketing-holder/contact" mode="line"/>
						<br/>
						
						Name and address of Contact<sup>4</sup>:<br/>
						<xsl:apply-templates select="declaration-contact/dossier/person-com-after-authorisation/contact-name" mode="data"/><br/>
						<xsl:apply-templates select="declaration-contact/dossier/person-com-after-authorisation/company-name" mode="data"/><br/>
						<xsl:apply-templates select="declaration-contact/dossier/person-com-after-authorisation/contact" mode="line">
							<xsl:with-param name="phone">y</xsl:with-param>
							<xsl:with-param name="fax">y</xsl:with-param>
							<xsl:with-param name="email">y</xsl:with-param>
						</xsl:apply-templates>
						<br/>
						
						Applicant's reference: <xsl:apply-templates select="declaration-contact/applicant-reference" mode="data"/><br/>
					</td>
				</tr>
			</table>
			<table width="100%">
				<tr>
					<td valign="top"><font size="-2"><sup>1</sup></font></td>
					<td>
						<font size="-2">
							<u>Human Medicinal Products:</u> : Number to be completed by the Marketing Authorisation Holder, reflecting the correct sequential Mutual 	Recognition Procedure Number according to Volume 2A, Chapter 2, 7. Numbering System for the Procedures for Mutual Recognition as 	published on the Website of the European Commission (<a href="http://ec.europa.eu/enterprise/pharmaceuticals/eudralex/homev2.htm">http://ec.europa.eu/enterprise/pharmaceuticals/eudralex/homev2.htm</a>)<br/> 
							<u>Veterinary Medicinal Products:</u> Renewal number to be issued by the Reference Member State before submission of the application according 	to the corresponding CMD(v) Best Practice Guide (<a href="http://www.hma.eu">http://www.hma.eu</a>)
						</font>
					</td>
				</tr>
				<tr>
					<td valign="top"><font size="-2"><sup>2</sup></font></td>
					<td>
						<font size="-2">
							For centrally authorised products a list of EU Member States / Norway / Iceland where the product is on the market should be provided in a 
        separate appendix
						</font>
					</td>
				</tr>
				<tr>
					<td valign="top"><font size="-2"><sup>3</sup></font></td>
					<td>
						<font size="-2">
							For centrally authorised products this information, including packaging and pack size(s), should be provided in tabular format in a separate 
       appendix (cf. Annex A to CHMP/CVMP Opinion)
						</font>
					</td>
				</tr>
				<tr>
					<td valign="top"><font size="-2"><sup>4</sup></font></td>
					<td>
						<font size="-2">
							As specified in section 2.4.3 in Part 1A. If different, attach letter of authorisation
						</font>
					</td>
				</tr>
			</table>
		</center>
		<br/>
	</xsl:template>
	
	<xsl:template name="decision">
		<br/><br/>
			<table width="100%" cellpadding="5" cellspacing="0" border="1" frame="border" rules="all">
				<tr>
					<td width="50%" valign="top">
						Date of first authorisation in Reference Member State/Community: 
						<xsl:apply-templates select="//declaration-authorisation/date-first-authorisation-ms" mode="data-date"/>
						<br/><br/>
						Date of expiry of current authorisation in Reference Member State/Community: 
						<xsl:apply-templates select="//declaration-authorisation/date-expiry-current-ms" mode="data-date"/>
					</td>
					<td width="50%" valign="top">
						Date of first authorisation in the Concerned Member State to which this application is made: 
						<xsl:apply-templates select="//declaration-authorisation/date-first-authorisation-cms" mode="data-date"/>
						<br/><br/>
						Date of expiry of current authorisation in the Concerned Member State: 
						<xsl:apply-templates select="//declaration-authorisation/date-expiry-current-cms" mode="data-date"/>
					</td>
				</tr>
				<tr>
					<td></td>
					<td valign="top">
						Proposed Common Renewal Date: 
						<xsl:apply-templates select="//declaration-authorisation/date-proposed-common-renewal" mode="data-date"/>
					</td>
				</tr>
			</table>
	</xsl:template>
	
	<xsl:template match="contact" mode="line">
		<xsl:param name="phone">n</xsl:param>
		<xsl:param name="fax">n</xsl:param>
		<xsl:param name="email">n</xsl:param>
	
		<xsl:if test="count(address01) > 0"><xsl:apply-templates select="address01" mode="data"/><br/></xsl:if>
		<xsl:if test="count(address02) > 0"><xsl:apply-templates select="address02" mode="data"/><br/></xsl:if>
		<xsl:if test="count(zipcode) + count(town) > 0">
			<xsl:apply-templates select="zipcode" mode="data"/>
			<xsl:apply-templates select="town" mode="data"/><br/>
		</xsl:if>
		<xsl:apply-templates select="country" mode="data"/><br/>
		<xsl:if test="string-length(phone) > 0 or $phone = 'y'">Telephone number: <xsl:apply-templates select="phone" mode="data"/><br/></xsl:if>
		<xsl:if test="string-length(fax) > 0 or $fax = 'y'">Fax number: <xsl:apply-templates select="fax" mode="data"/><br/></xsl:if>
		<xsl:if test="string-length(email) > 0 or $email = 'y'">E-mail: <xsl:apply-templates select="email" mode="data"/><br/></xsl:if>
	</xsl:template>
	
	<xsl:template match="manufacturers">
		<br/><br/>
		<table width="100%" cellpadding="5" cellspacing="0" border="1" frame="border" rules="groups">
			<tr>
				<td>
					<b>APPROVED MANUFACTURERS</b><br/><br/>
					
					Authorised manufacturer(s) (or importer) responsible for <b>batch release</b> in the EEA (in accordance with Articles 40 and 51 of Directive 2001/83/EC, as amended, or Articles 44 and 55 of Directive 2001/82/EC (as shown in the package leaflet and where applicable in the labelling or Annex II of the Decision)
				</td>
			</tr>
			<xsl:for-each select="manufacturers-batch-release/manufacturer-batch-release">
				<xsl:call-template name="contact-address"/>
			</xsl:for-each>
			<tr>
				<td><i>Further manufacturers responsible for batch release can be detailed in the text field below, in the same format as shown above.</i></td>
			</tr>
			<tr>
				<td>
					<br/>
					<b>For blood products and vaccines:</b><br/>
						State laboratory or laboratory designated for official <b>batch release</b>, as accordance with Articles 111(1), 113, 114 (1)-(2) and 115 of Directive 2001/83/EC as amended.
				</td>
			</tr>
			<xsl:choose>
				<xsl:when test="count(manufacturers-batch-release/contact-blood-vaccines) = 0">
					<xsl:call-template name="contact-address"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="manufacturers-batch-release/contact-blood-vaccines">
						<xsl:call-template name="contact-address"/>
					</xsl:for-each>
				</xsl:otherwise>	
			</xsl:choose>
			<tr>
				<td><i>Further manufacturers responsible for batch release can be detailed in the text field below, in the same format as shown above.</i></td>
			</tr>
			<tr>
				<td>
					<br/>
					Site(s) in EEA or in countries where an MRA or other Community arrangements apply, where <b>batch control/testing</b> takes place, as required by Article 51 of Directive 2001/83/EC as amended or Article 55 of Directive 2001/82/EC, if different from above:
				</td>
			</tr>
			<xsl:choose>
				<xsl:when test="count(manufacturers-batch-release/contact-batch-testing-site) = 0">
					<xsl:call-template name="contact-address"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="manufacturers-batch-release/contact-batch-testing-site">
						<xsl:call-template name="contact-address"/>
					</xsl:for-each>
				</xsl:otherwise>	
			</xsl:choose>
			<tr>
				<td><i>Further sites can be detailed in the text field below, in the same format as shown above.</i></td>
			</tr>
			<tr>
				<td>
					<br/>
					Manufacturer(s) of the <b>medicinal product</b> and site(s) of manufacture (including diluent and solvent manufacturing sites):
				</td>
			</tr>
			<xsl:for-each select="pharma-product-manufacturers/pharma-product-manufacturer">
				<xsl:call-template name="contact-address"/>
			</xsl:for-each>
			<tr>
				<td><i>Further manufacturers can be detailed in the text field below, in the same format as shown above.</i></td>
			</tr>
			<tr>
				<td>
					<br/>
					Manufacturer(s) of the <b>active substance(s)</b><br/>
					<i>Note: All manufacturing sites involved in the manufacturing process of each source of active substance should be listed.  Broker or supplier details alone are not sufficient</i>
				</td>
			</tr>
			<xsl:for-each select="manufacturers-active-substance/manufacturer-active-substance">
				<xsl:call-template name="contact-address"/>
			</xsl:for-each>
			<tr>
				<td><i>Further active substance manufacturers can be detailed in the text field below, in the same format as shown above.</i></td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template name="contact-address">
		<tr>
			<td>
				<table width="100%">
					<xsl:if test="position() > 1">
						<tr><td><hr/></td></tr>
					</xsl:if>
					<tr>
						<td width="20%">Company Name:</td>
						<td width="80%">
							<xsl:apply-templates select="company-name" mode="data"/>
						</td>
					</tr>
					<tr>
						<td valign="top">Address:</td>
						<td>
							<xsl:apply-templates select="contact/address01" mode="line"/>
							<xsl:apply-templates select="contact/address02" mode="line"/>
							<xsl:apply-templates select="contact/zipcode" mode="data"/>
							<xsl:apply-templates select="contact/town" mode="data"/>
						</td>
					</tr>
					<tr>
						<td>Country:</td>
						<td>
							<xsl:apply-templates select="contact/country" mode="data"/>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="100%">
								<tr>
									<td width="10%">Telephone:</td>
									<td width="20%"><xsl:apply-templates select="contact/phone" mode="data"/></td>
									<td width="10%">Telefax:</td>
									<td width="20%"><xsl:apply-templates select="contact/fax" mode="data"/></td>
									<td width="10%">E-mail:</td>
									<td width="20%"><xsl:apply-templates select="contact/email" mode="data"/></td>
								</tr>
							</table>
						</td>
					</tr>
					<xsl:if test="count(description-functions) > 0">
						<tr>
							<td colspan="2">
								<br/>
								Brief description of functions performed by manufacturer of dosage form/assembler, etc: 
								<xsl:apply-templates select="description-functions" mode="data"/>
							</td>
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>	
	</xsl:template>
	
	<xsl:template match="qualitative-quantitative-composition">
		<br/><br/>
 		<table width="100%" cellpadding="5" cellspacing="0" border="1" frame="border" rules="groups">
			<tr>
				<td>
					<b>QUALITATIVE AND QUANTITATIVE COMPOSITION IN TERMS OF THE ACTIVE SUBSTANCE(S) AND THE  EXCIPIENT(S)</b><br/>
					<i>(For centrally authorised products the composition should be provided separately in tabular format as part of the Quality Expert Statement.)</i>
				</td>
			</tr>
			<xsl:apply-templates select="composition"/>
		</table>
	</xsl:template>
	
	<xsl:template match="composition">
		<tr>
			<td>
				<i>A note should be given as to which quantity the composition refers (e.g. 1 capsule):</i><xsl:apply-templates select="quantity-note" mode="data"/>
				<br/>
				<i>List the active substance(s) separately from the excipient(s)</i>
				<br/><br/>
				<table width="80%">
					<tr>
						<td width="5%"/>
						<td width="50%">Name of active substance*(s)</td>
						<td width="10%">Quantity</td>
						<td width="10%">Unit</td>
						<td width="25%">Monograph standard</td>
					</tr>
					<xsl:apply-templates select="substance-info"/>
				</table>
				<br/>
				<table width="80%">
					<tr>
						<td width="5%"/>
						<td width="50%">Name of excipient*(s)</td>
						<td width="10%">Quantity</td>
						<td width="10%">Unit</td>
						<td width="25%">Monograph standard</td>
					</tr>
					<xsl:apply-templates select="excipient-info"/>
				</table>
				<br/>
				<i>
					*Only one name should be given, in the following order of priority: INN, Ph. Eur., National Pharmacopoeia, common name, scientific name. The active substance should be declared by its recommended INN, accompanied by its salt or hydrate form if relevant.
				</i>
				<br/><br/>
				Details of any overages should <b>not</b> be included in the formulation columns but stated below:
				<table width="50%">
					<tr>
						<td width="5%"/>
						<td width="60%">Name of active substance(s)*</td>
						<td width="35%">overage</td>
					</tr>
					<xsl:apply-templates select="substance-info" mode="overage"/>
				</table>
				<br/>
				<table width="50%">
					<tr>
						<td width="5%"/>
						<td width="60%">excipient(s)*</td>
						<td width="35%">overage</td>
					</tr>
					<xsl:apply-templates select="excipient-info" mode="overage"/>
				</table>
			</td>
		</tr>
	</xsl:template>	
	
	<xsl:template match="substance-info">
		<tr>
			<td/>
			<td><xsl:apply-templates select="substance-name" mode="data"/></td>
			<td><xsl:apply-templates select="strength-quantity" mode="data"/></td>
			<td><xsl:apply-templates select="strength-unit" mode="data"/></td>
			<td><xsl:apply-templates select="reference-monograph-standard" mode="data"/></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="excipient-info">
		<tr>
			<td/>
			<td><xsl:apply-templates select="excipient-name" mode="data"/></td>
			<td><xsl:apply-templates select="strength-quantity" mode="data"/></td>
			<td><xsl:apply-templates select="strength-unit" mode="data"/></td>
			<td><xsl:apply-templates select="reference-monograph-standard" mode="data"/></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="substance-info" mode="overage">
		<tr>
			<td/>
			<td><xsl:apply-templates select="substance-name" mode="data"/></td>
			<td><xsl:apply-templates select="overage" mode="data"/></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="excipient-info" mode="overage">
		<tr>
			<td/>
			<td><xsl:apply-templates select="excipient-name" mode="data"/></td>
			<td><xsl:apply-templates select="overage" mode="data"/></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="present-proposed-changes">
		<br/><br/>
		<i>(If revised product information (<u>SPC, Labelling and/or Package Leaflet</u>) is proposed to take account of issues raised by the expert, specify the precise present and proposed wording, underlining or highlighting the changed words. Alternatively, such listing may be provided as a separate document attached to the application form).</i>
		<br/><br/>
		<table width="100%" cellpadding="5" cellspacing="0" border="1" frame="border" rules="all">
			<tr>
				<td width="50%" align="center"><b>PRESENT PRODUCT INFORMATION TEXT</b></td>
				<td width="50%" align="center"><b>PROPOSED PRODUCT INFORMATION TEXT</b></td>
			</tr>
			<tr>
				<td valign="top"><xsl:apply-templates select="present" mode="data-pre"/></td>
				<td valign="top"><xsl:apply-templates select="proposed" mode="data-pre"/></td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="amended-product-information">
		<br/><br/>
		<table width="100%" cellpadding="2" cellspacing="0" border="1" frame="box" rules="none">
			<tr>
				<td colspan="2">
					<b>DOCUMENTS APPENDED TO THIS APPLICATION</b><br/>
					<br/>
					Note:
					<ul class="level-1">
						<li><i>In case of a human authorisation, delete the complete list of veterinary documents.</i></li>
						<li><i>In case of a veterinary authorisation, delete the complete list of human documents.</i></li>
					</ul>
				</td>
			</tr>
			<xsl:apply-templates select="amended-product-information-human"/>
			<xsl:apply-templates select="amended-product-information-human" mode="footnote"/>
			<xsl:apply-templates select="amended-product-information-vet"/>
			<xsl:apply-templates select="amended-product-information-vet" mode="footnote"/>
		</table>
	</xsl:template>
			
	<xsl:template match="amended-product-information-human">
			<tr>
				<td colspan="2">
					<br/>
					<b>FOR HUMAN MEDICINAL PRODUCTS ONLY</b>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<br/>
					<b>Module 1:</b>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-cover-letter)"/>
					</xsl:call-template>
					1.0
				</td>
				<td width="90%">
					Cover Letter
					<xsl:apply-templates select="//ann-cover-letter" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-comprehensive-toc)"/>
					</xsl:call-template>
					1.1
				</td>
				<td>
					Comprehensive table of content
					<xsl:apply-templates select="//ann-comprehensive-toc" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-following-annex)"/>
					</xsl:call-template>
					1.2
				</td>
				<td>
					Renewal Application Form with the following annexes: 
					<xsl:apply-templates select="//ann-following-annex" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-authorised-product)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							A list of all authorised product presentations for which renewal is sought in tabular format
							<xsl:apply-templates select="//ann-authorised-product" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top"></td>
				<td>
					<ul class="level-1">
						<li>Details on contact persons</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-person-pharmacovigilance)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-2">
						<li>
							Qualified person in the EEA for Pharmacovigilance
							<xsl:apply-templates select="//ann-person-pharmacovigilance" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-person-product-defects)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-2">
						<li>
							Contact person in the EEA with overall responsibility for product defects and recalls
							<xsl:apply-templates select="//ann-person-product-defects" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-person-scientific-service)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-2">
						<li>
							Contact person for scientific service in the EEA in charge of information about the medicinal product
							<xsl:apply-templates select="//ann-person-scientific-service" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-list-eu-member-state)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							List of EU Member States / Norway / Iceland where the product is on the market and indicating for each country which presentations are marketed and the launch date
							<xsl:apply-templates select="//ann-list-eu-member-state" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-post-authorisation)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							Chronological list of all post-authorisation submissions since grant of the Marketing Authorisation or last renewal: a list of all approved or pending Type IA/IB and Type II variations, Extensions, Art 61(3) Notifications, USR, giving the procedure number (where applicable), date of submission, date of approval (if approved) and brief description of the change.
							<xsl:apply-templates select="//ann-post-authorisation" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-follow-up-measures)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							Chronological list of Follow-up measures, and for Community Authorisations only, any Specific Obligations submitted since grant of marketing authorisation or last renewal indicating scope, status, date of submission and date when issue has been resolved (where applicable)
							<xsl:apply-templates select="//ann-follow-up-measures" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-revised-follow-up-measures)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							Revised list of all remaining Follow-up measures/post-authorisation commitments, and for Community Authorisations only any Specific Obligations and signed letter of commitment  (where applicable)
							<xsl:apply-templates select="//ann-revised-follow-up-measures" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-certificate-gmp-compliance)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							A statement, or when available, a certificate of GMP compliance, not more than three years old, for the manufacturer(s) of the medicinal product listed in the application issued by an EEA competent authority or MRA partner authority. A reference to the Community EudraGMP database will suffice, once this is available.
							<xsl:apply-templates select="//ann-certificate-gmp-compliance" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-list-gmp-inspections)"/>
					</xsl:call-template>
				</td>
				<td>
					<ul class="level-1">
						<li>
							For manufacturing sites of the medicinal product not located in the EEA or in the territory of an MRA partner, a list of the most recent GMP inspections carried out by other authorities indicating the date, inspection team and outcome
							<xsl:apply-templates select="//ann-list-gmp-inspections" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-person-mah-material)"/>
					</xsl:call-template>
				</td>
				<td>
					A declaration by the Qualified Person (QP) of each of the manufacturing authorisation holders (i.e. located in the EEA) listed in the application form where the active substance(s) is used as a starting material, that the active substance(s) is manufactured in accordance with the guidelines on good manufacturing practice for starting materials as adopted by the Community<sup>5</sup>
					<xsl:apply-templates select="//ann-person-mah-material" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-person-mah-batch-release)"/>
					</xsl:call-template>
				</td>
				<td>
					Where different, a declaration by the Qualified Person (QP) of the manufacturing authorisation holder(s) listed in the application form as responsible for batch release, that the active substance(s) is manufactured in accordance with the guidelines on good manufacturing practice for starting materials as adopted by the Community<sup>5</sup>
					<xsl:apply-templates select="//ann-person-mah-batch-release" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-spc) + count(amended-module-1/attach-labeling) + count(amended-module-1/attach-package-leaflet)"/>
					</xsl:call-template>
					1.3.1
				</td>
				<td>
					SPC, Labelling and Package Leaflet
					<xsl:apply-templates select="//ann-spc" mode="annex"/>
					<xsl:apply-templates select="//ann-labeling" mode="annex"/>
					<xsl:apply-templates select="//ann-package-leaflet" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-specimens)"/>
					</xsl:call-template>
					1.3.3
				</td>
				<td>
					Specimen (for Community Authorisations only)
					<xsl:apply-templates select="//ann-specimens" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-information-expert)"/>
					</xsl:call-template>
					1.4
				</td>
				<td>
					Information about the expert
					<xsl:apply-templates select="//ann-information-expert" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-quality-cv)"/>
					</xsl:call-template>
					1.4.1
				</td>
				<td>
					Quality (incl. Signature + CV)
					<xsl:apply-templates select="//ann-quality-cv" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-non-clinical-cv)"/>
					</xsl:call-template>
					1.4.2
				</td>
				<td>
					Non-clinical (incl. Signature + CV) - if applicable (for Community Authorisations only)
					<xsl:apply-templates select="//ann-non-clinical-cv" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-1/attach-clinical-cv)"/>
					</xsl:call-template>
					1.4.3
				</td>
				<td class="level-2">
					Clinical (incl. Signature + CV)
					<xsl:apply-templates select="//ann-clinical-cv" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<br/>
					<b>Module 2:</b>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-2/attach-quality-overview)"/>
					</xsl:call-template>
					2.3
				</td>
				<td class="level-2">
					Quality Overall Summary (Quality Expert Statement)
					<xsl:apply-templates select="//ann-quality-overview" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-2/attach-nonclinical-overview)"/>
					</xsl:call-template>
					2.4
				</td>
				<td class="level-2">
					Non-clinical Overview (Non-clinical Expert Statement) - if applicable (for Community Authorisations only)
					<xsl:apply-templates select="//ann-nonclinical-overview" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-2/attach-clinical-overview)"/>
					</xsl:call-template>
					2.5
				</td>
				<td class="level-2">
					Clinical Overview (Clinical Expert Statement)
					<xsl:apply-templates select="//ann-clinical-overview" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<br/>
					<b>Module 5:</b>
				</td>
			</tr>
			<tr>
				<td valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(amended-module-5/attach-report-post-marketing)"/>
					</xsl:call-template>
					5.3.6
				</td>
				<td class="level-2">
					Reports of Post-marketing experience (Periodic Safety Update Report and Summary Bridging Report if applicable)
					<xsl:apply-templates select="//ann-report-post-marketing" mode="annex"/>
				</td>
			</tr>
	</xsl:template>
	
	<xsl:template match="amended-product-information-human" mode="footnote">
			<tr>
				<td valign="top" width="10%" align="right"><font size="-2"><sup>5</sup></font></td>
				<td width="90%">
					<font size="-2">
						Note: Where more than one Qualified Person (QP) is involved, a single declaration by one of the QPs that the active substance(s) used as a starting material are manufactured in accordance with the guidelines on good manufacturing practice for starting materials as adopted by the Community, may be submitted provided that: 
						<ul>
							<li>The declaration makes it clear that it is signed on behalf of all the involved QPs.</li>
							<li>The arrangements are underpinned by a technical agreement as described in Chapter 7 of the GMP Guide and the QP providing the declaration is the one identified in the agreement as taking specific responsibility for the GMP compliance of the active substance manufacturer(s).</li>
						</ul>
					</font>
				</td>
			</tr>
	</xsl:template>
	
	<xsl:template match="amended-product-information-vet">
			<tr>
				<td colspan="2">
					<br/>
					<b>FOR VETERINARY MEDICINAL PRODUCTS ONLY</b>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-cover-letter)"/>
					</xsl:call-template>
					1.0
				</td>
				<td width="90%">
					Cover Letter
					<xsl:apply-templates select="//ann-cover-letter" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-comprehensive-toc)"/>
					</xsl:call-template>
					1.1
				</td>
				<td width="90%">
					Comprehensive table of content
					<xsl:apply-templates select="//ann-comprehensive-toc" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-following-annex)"/>
					</xsl:call-template>
					2
				</td>
				<td width="90%">
					Renewal Application Form with the following annexes:
					<xsl:apply-templates select="//ann-following-annex" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-authorised-product)"/>
					</xsl:call-template>
					2.1
				</td>
				<td width="90%">
					List of all authorised product presentations for which renewal is sought in tabular format 
					<xsl:apply-templates select="//ann-authorised-product" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-person-pharmacovigilance) + count(attach-person-product-defects) + count(attach-holder)"/>
					</xsl:call-template>
					2.2
				</td>
				<td width="90%">
					Details on contact persons 
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-person-pharmacovigilance)"/>
					</xsl:call-template>
				</td>
				<td width="90%">
					<ul class="level-1">
						<li>
							Qualified person in the EEA for Pharmacovigilance and the QP for Pharmacovigilance in the MS, if different
							<xsl:apply-templates select="//ann-person-pharmacovigilance" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-person-product-defects)"/>
					</xsl:call-template>
				</td>
				<td width="90%">
					<ul class="level-1">
						<li>
							Contact person in the EEA with overall responsibility for product defects and recalls
							<xsl:apply-templates select="//ann-person-product-defects" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-holder)"/>
					</xsl:call-template>
				</td>
				<td width="90%">
					<ul class="level-1">
						<li>
							Contact person at the address of the Marketing Authorisation Holder (if different from the address of the contact person during the procedure)
							<xsl:apply-templates select="//ann-holder" mode="annex"/>
						</li>
					</ul>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-list-eu-member-state)"/>
					</xsl:call-template>
					2.3
				</td>
				<td width="90%">
					List of EU Member States / Norway / Iceland where the product is on the market and indicating for each country which presentations are marketed and the launch date 
					<xsl:apply-templates select="//ann-list-eu-member-state" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-post-authorisation)"/>
					</xsl:call-template>
					2.4
				</td>
				<td width="90%">
					Chronological list of all post authorisation submissions (variations, extensions etc.), follow-up measures and, for Community Authorisations only, any Specific Obligations submitted since grant of marketing authorisation or last renewal indicating scope, status, date of submission and date when issue has been resolved
					<xsl:apply-templates select="//ann-post-authorisation" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-revised-follow-up-measures)"/>
					</xsl:call-template>
					2.5
				</td>
				<td width="90%">
					Revised list of all remaining Follow-up measures and , for Community Authorisations only, any Specific Obligations and signed letter of commitment (where applicable)
					<xsl:apply-templates select="//ann-revised-follow-up-measures" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-proof-payment)"/>
					</xsl:call-template>
					2.6
				</td>
				<td width="90%">
					Proof of payment of fee, where relevant
					<xsl:apply-templates select="//ann-proof-payment" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-certificate-gmp-compliance)"/>
					</xsl:call-template>
					2.7
				</td>
				<td width="90%">
					A statement, or when available, a certificate of GMP compliance, not more than three years old, for the manufacturer(s) of the medicinal product listed in the application issued by an EEA competent authority or MRA partner authority. 
					<xsl:apply-templates select="//ann-certificate-gmp-compliance" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-list-gmp-inspections)"/>
					</xsl:call-template>
					2.8
				</td>
				<td width="90%">
					In addition, for manufacturing sites of the medicinal product not located in the EEA or in the territory of an MRA partner, a list of the most recent GMP inspections carried out by other authorities indicating the date, inspection team and outcome.
					<xsl:apply-templates select="//ann-list-gmp-inspections" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-person-mah-material)"/>
					</xsl:call-template>
					2.9
				</td>
				<td width="90%">
					A declaration by the Qualified Person (QP) of each of the manufacturing authorisation holders (i.e. located in the EEA) listed in the application form where the active substance(s) is used as a starting material, that the active substance(s) is manufactured in accordance with the guidelines on good manufacturing practice for starting materials as adopted by the Community<sup>6</sup> 
					<xsl:apply-templates select="//ann-person-mah-material" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-person-mah-batch-release)"/>
					</xsl:call-template>
					2.10
				</td>
				<td width="90%">
					Where different, a declaration by the Qualified Person (QP) of the manufacturing authorisation holder(s) listed in the application form as responsible for batch release, that the active substance(s) is manufactured in accordance with the guidelines on good manufacturing practice for starting materials as adopted by the Community<sup>6</sup>
					<xsl:apply-templates select="//ann-person-mah-batch-release" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-spc) + count(attach-labeling) + count(attach-package-leaflet)"/>
					</xsl:call-template>
					3
				</td>
				<td width="90%">
					SPC, Labelling and Package Leaflet 
					<xsl:apply-templates select="//ann-spc" mode="annex"/>
					<xsl:apply-templates select="//ann-labeling" mode="annex"/>
					<xsl:apply-templates select="//ann-package-leaflet" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-quality-overview)"/>
					</xsl:call-template>
					4
				</td>
				<td width="90%">
					Quality expert statement, including: 
					<xsl:apply-templates select="//ann-quality-overview" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-currently-specifications)"/>
					</xsl:call-template>
					4.1
				</td>
				<td width="90%">
					Currently authorised specifications for the active substance and the finished product. 
					<xsl:apply-templates select="//ann-currently-specifications" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-composition)"/>
					</xsl:call-template>
					4.2
				</td>
				<td width="90%">
					Qualitative and quantitative composition in terms of the active substance(s) and the excipient(s)
					<xsl:apply-templates select="//ann-composition" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-clinical-overview)"/>
					</xsl:call-template>
					5
				</td>
				<td width="90%">
					Clinical expert statement 
					<xsl:apply-templates select="//ann-clinical-overview" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-safety-expert-statement)"/>
					</xsl:call-template>
					6
				</td>
				<td width="90%">
					Safety expert statement
					<xsl:apply-templates select="//ann-safety-expert-statement" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-periodic-safety-report)"/>
					</xsl:call-template>
					7
				</td>
				<td width="90%">
					Periodic Safety Update Report and Summary Bridging Report if applicable
					<xsl:apply-templates select="//ann-periodic-safety-report" mode="annex"/>
				</td>
			</tr>
			<tr>
				<td width="10%" valign="top">
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(attach-declaration-current-tse)"/>
					</xsl:call-template>
					8
				</td>
				<td width="90%">
					Declaration of current TSE status
					<xsl:apply-templates select="//ann-declaration-current-tse" mode="annex"/>
				</td>
			</tr>
	</xsl:template>
	
	<xsl:template match="amended-product-information-vet" mode="footnote">
			<tr>
				<td valign="top" align="right"><font size="-2"><sup>6</sup></font></td>
				<td>
					<font size="-2">
						Note: Where more than one Qualified Person (QP) is involved, a single declaration by one of the QPs that the active substance(s) used as a starting material are manufactured in accordance with the guidelines on good manufacturing practice for starting materials as adopted by the Community, may be submitted provided that: 
						<ul>
							<li>The declaration makes it clear that it is signed on behalf of all the involved QPs.</li>
							<li>The arrangements are underpinned by a technical agreement as described in Chapter 7 of the GMP Guide and the QP providing the declaration is the one identified in the agreement as taking specific responsibility for the GMP compliance of the active substance manufacturer(s).</li>
						</ul>
					</font>
				</td>
			</tr>
	</xsl:template>
	
	<xsl:template match="declaration-info">
		<br/><br/>
		<table width="100%" cellpadding="2" cellspacing="0" border="1" frame="box" rules="none">
			<tr>
				<td colspan="4">
					I hereby make application for the above Marketing Authorisation to be renewed.  I declare that the quality of the product, in respect of the methods of preparation and control, has been regularly updated by variation procedure to take account of technical and scientific progress in accordance with Article 23 of Directive 2001/83/EC or Article 27 (1) of Directive 2001/82/EC or Article 16 of Regulation (EC) No 726/2004. The product conforms with current CHMP/CVMP quality guidelines where relevant.  I confirm that no changes have been made to the product particulars other than those approved by the Competent Authority.
				</td>
			</tr>
			<tr>
				<td colspan="4">
					Fees paid or will be paid, if applicable 
					<xsl:call-template name="checkbox">
						<xsl:with-param name="value" select="count(fees-paid)"/>
					</xsl:call-template>
					Amount/Currency
					<xsl:apply-templates select="fees-amount" mode="data"/>
				</td>
			</tr>
			<tr>
				<td width="25%"><b>Main Signatory</b></td>
				<td width="25%"><xsl:apply-templates select="main-signature" mode="data"/></td>
				<td width="25%">Status (Job title)</td>
				<td width="25%"><xsl:apply-templates select="function-person" mode="data"/></td>
			</tr>
			<tr>
				<td>Print name</td>
				<td><xsl:apply-templates select="name-person" mode="data"/></td>
				<td>Date </td>
				<td><xsl:apply-templates select="date-signature" mode="data-date"/></td>
			</tr>
			<tr>
				<td><b>Second Signatory</b><br/><i>(where appropriate)</i></td>
				<td><xsl:apply-templates select="second-signature" mode="data"/></td>
				<td>Status (Job title)</td>
				<td><xsl:apply-templates select="function-person-authorised" mode="data"/></td>
			</tr>
			<tr>
				<td>Print name</td>
				<td><xsl:apply-templates select="person-authorised" mode="data"/></td>
				<td>Date</td>
				<td><xsl:apply-templates select="date-second-signature" mode="data-date"/></td>
			</tr>
		</table>
	</xsl:template>
	
</xsl:stylesheet>